@@ -88,6 +88,12 @@ def test_read_esri_wkt():
         }
 
 
+def test_read_no_crs():
+    """crs of a dataset with no SRS is None"""
+    with rasterio.open('tests/data/389225main_sw_1965_1024.jpg') as src:
+        assert src.crs is None
+
+
 # Ensure that CRS sticks when we write a file.
 @pytest.mark.gdalbin
 def test_write_3857(tmpdir):
@@ -385,3 +391,43 @@ def test_implicit_proj_dict(projection_string):
 def test_capitalized_epsg_init():
     """Ensure that old behavior is preserved"""
     assert CRS(init='EPSG:4326').to_epsg() == 4326
+
+
+def test_issue1609_wktext_a():
+    """Check on fix of issue 1609"""
+    src_proj = {'ellps': 'WGS84',
+            'proj': 'stere',
+            'lat_0': -90.0,
+            'lon_0': 0.0,
+            'x_0': 0.0,
+            'y_0': 0.0,
+            'lat_ts': -70,
+            'no_defs': True}
+    wkt = CRS(src_proj).wkt
+    assert 'PROJECTION["Polar_Stereographic"]' in wkt
+    assert 'PARAMETER["latitude_of_origin",-70]' in wkt
+
+
+def test_issue1609_wktext_b():
+    """Check on fix of issue 1609"""
+    dst_proj = {'ellps': 'WGS84',
+               'h': 9000000.0,
+               'lat_0': -78.0,
+               'lon_0': 0.0,
+               'proj': 'nsper',
+               'units': 'm',
+               'x_0': 0,
+               'y_0': 0,
+               'wktext': True}
+    wkt = CRS(dst_proj).wkt
+    assert '+wktext' in wkt
+
+
+def test_empty_crs_str():
+    """str(CRS()) should be empty string"""
+    assert str(CRS()) == ''
+
+
+def test_issue1620():
+    """Different forms of EPSG:3857 are equal"""
+    assert CRS.from_wkt('PROJCS["WGS 84 / Pseudo-Mercator",GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4326"]],PROJECTION["Mercator_1SP"],PARAMETER["central_meridian",0],PARAMETER["scale_factor",1],PARAMETER["false_easting",0],PARAMETER["false_northing",0],UNIT["metre",1,AUTHORITY["EPSG","9001"]],AXIS["X",EAST],AXIS["Y",NORTH],EXTENSION["PROJ4","+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs"],AUTHORITY["EPSG","3857"]]') == CRS.from_dict(init='epsg:3857')
